@@ -1,4 +1,4 @@
-﻿/*
+/*
  *     XaoS, a fast portable realtime fractal zoomer
  *                  Copyright (C) 1996 by
  *
@@ -23,6 +23,7 @@
 #include <cctype>
 #include <cerrno>
 #include <climits>
+#include <clocale>
 #include <cmath>
 #include <csignal>
 #include <cstdlib>
@@ -320,12 +321,12 @@ static void ui_about(struct uih_context *uih)
             QSysInfo::kernelType() + " " +
             // QSysInfo::kernelVersion() + " "
             // QSysInfo::buildAbi() + " " +
-            QSysInfo::buildCpuArchitecture() +
+            QSysInfo::buildCpuArchitecture() + ", Qt " + QT_VERSION_STR +
             ")"
             "<br>"
             "Fast interactive real-time fractal zoomer/morpher<br><br>"
             "Original Authors: Jan Hubička and Thomas Marsh<br>"
-            "Copyright © 1996-2020 XaoS Contributors<br>"
+            "Copyright © 1996-2023 XaoS Contributors<br>"
             "<br>"
             "This program is free software; you can redistribute it and/or modify "
             "it under the terms of the GNU General Public License as published by "
@@ -362,12 +363,16 @@ void uih_setlanguage(uih_context *c, int l)
     settings.setValue("MainWindow/language", lang2(l));
     QMessageBox msgBox;
     msgBox.setText(TR("Message", "XaoS must restart to change the language."));
+#ifndef __wasm
     msgBox.setInformativeText(TR("Message", "Do you want to quit now?"));
     msgBox.setStandardButtons(QMessageBox::Yes | QMessageBox::No);
+#endif
     int ret = msgBox.exec();
+#ifndef __wasm
     if (ret == QMessageBox::Yes) {
         exit(0);
     }
+#endif
 }
 
 #ifndef Q_OS_MAC
@@ -393,7 +398,7 @@ static int ui_fullscreenselected(struct uih_context *uih)
 #endif
 
 /* WARNING: Increase this number in case there are new menu items added. */
-#define MAX_MENUITEMS_I18N 33
+#define MAX_MENUITEMS_I18N 34
 /* These variables must be global: */
 static menuitem *menuitems;
 static menuitem menuitems_i18n[MAX_MENUITEMS_I18N];
@@ -414,10 +419,10 @@ char languageSetting[6] = "";
 bool languageSysDefault = true;
 // please keep the languages in the same order
 const char *languages1[] = {
-    "__", "cs", "en", "fr", "de", "hi", "hu", "is", "it", "pt", "ro", "ru", "rs", "es", "sv", "vi"
+    "__", "cs", "en", "fr", "de", "he", "hi", "hu", "is", "it", "pt", "ro", "ru", "rs", "es", "sv", "vi"
 };
 const char *languages2[] = {
-    "_____", "cs_CZ", "en_US", "fr_FR", "de_DE", "hi_HI", "hu_HU", "is_IS", "it_IT", "pt_PT", "ro_RO", "ru_RU", "rs_RS", "es_ES", "sv_SV", "vi_VN"
+    "_____", "cs_CZ", "en_US", "fr_FR", "de_DE", "he_IL", "hi_HI", "hu_HU", "is_IS", "it_IT", "pt_PT", "ro_RO", "ru_RU", "rs_RS", "es_ES", "sv_SV", "vi_VN"
 };
 
 const char *lang1(int i) {
@@ -476,8 +481,10 @@ static void ui_registermenus_i18n(void)
 {
     int no_menuitems_i18n =
         ui_no_menuitems_i18n; /* This variable must be local. */
+#ifndef __wasm
     MENUINT_I("file", NULL, TR("Menu", "Quit"), "quit",
               MENUFLAG_INTERRUPT | MENUFLAG_ATSTARTUP, ui_quit, UI);
+#endif
 
     MENUNOP_I("ui", NULL, TR("Menu", "Message Font..."), "font", UI, ui_font);
     MENUNOP_I("uia", NULL, TR("Menu", "Message Font..."), "font", UI, ui_font);
@@ -495,6 +502,8 @@ static void ui_registermenus_i18n(void)
                 UIH_LANG_FR, ui_languageselected);
     MENUINTRB_I("setlang", NULL, "German", "de", UI, uih_setlanguage,
                 UIH_LANG_DE, ui_languageselected);
+    MENUINTRB_I("setlang", NULL, "Hebrew", "he", UI, uih_setlanguage,
+                UIH_LANG_HE, ui_languageselected);
     MENUINTRB_I("setlang", NULL, "Hindi", "hi", UI, uih_setlanguage,
                 UIH_LANG_HI, ui_languageselected);
     MENUINTRB_I("setlang", NULL, "Hungarian", "hu", UI, uih_setlanguage,
@@ -577,15 +586,6 @@ int main(int argc, char *argv[])
     srand(time(NULL));
 
     QSettings settings;
-    if (defthreads == 0) {
-        // defthreads will be 0 if -threads command line option was not given
-        // so load it from saved settings instead
-        defthreads = settings.value("MainWindow/threadCount", 1).toInt();
-    } else {
-        // -threads command line option was given, so save it to settings
-        settings.setValue("MainWindow/threadCount", defthreads);
-    }
-    xth_init(defthreads);
 
     char *l = new char[6];
     strcpy(l, settings.value("MainWindow/language").toString().toStdString().c_str());
@@ -609,6 +609,16 @@ int main(int argc, char *argv[])
         exit(-1);
     }
 
+    if (defthreads == 0) {
+        // defthreads will be 0 if -threads command line option was not given
+        // so load it from saved settings instead
+        defthreads = settings.value("MainWindow/threadCount", 1).toInt();
+    } else {
+        // -threads command line option was given, so save it to settings
+        settings.setValue("MainWindow/threadCount", defthreads);
+    }
+    xth_init(defthreads);
+
     int i = ui_render();
     if (i) {
         ui_unregistermenus();
